@@ -1,6 +1,7 @@
+from pyston.order.exceptions import OrderIdentifierError
 from pyston.order.managers import BaseParserModelOrderManager
 from pyston.order.sorters import BaseSorter
-from pyston.order.utils import DIRECTION
+from pyston.order.utils import DirectionSlug
 from pyston.utils import LOOKUP_SEP
 
 
@@ -8,7 +9,7 @@ class ElasticsearchSorter(BaseSorter):
 
     def get_order_term(self):
         term = LOOKUP_SEP.join(self.identifiers)
-        return f'-{term}' if self.direction == DIRECTION.DESC else term
+        return f'-{term}' if self.direction == DirectionSlug.DESC else term
 
 
 class ElasticsearchOrderManager(BaseParserModelOrderManager):
@@ -22,6 +23,10 @@ class ElasticsearchOrderManager(BaseParserModelOrderManager):
                                order_fields_rfs):
         if len(identifiers) == 1:
             current_identifier = self._get_real_field_name(resource, identifiers[0])
+
+            if current_identifier not in order_fields_rfs:
+                raise OrderIdentifierError
+
             try:
                 field = model._doc_type.mapping.properties[current_identifier]
                 field_name = field.name
